==> amity-sdk-6.33.1-sources.jar: main/com/amity/socialcloud/sdk/chat/data/channel/membership/paging/ChannelMembershipMediator.kt <==
package com.amity.socialcloud.sdk.chat.data.channel.membership.paging

import co.amity.rxbridge.toRx2
import com.amity.socialcloud.sdk.api.chat.member.query.AmityChannelMembership
import com.amity.socialcloud.sdk.api.chat.member.query.AmityChannelMembershipSortOption
import com.amity.socialcloud.sdk.chat.data.channel.membership.ChannelMembershipQueryPersister
import com.amity.socialcloud.sdk.chat.data.channel.membership.ChannelMembershipRemoteDataStore
import com.amity.socialcloud.sdk.chat.data.channel.membership.ChannelMembershipRepository
import com.amity.socialcloud.sdk.infra.retrofit.request.QueryOptionsRequestParams
import com.amity.socialcloud.sdk.model.chat.member.AmityChannelMember
import com.amity.socialcloud.sdk.model.chat.member.AmityMembershipType
import com.amity.socialcloud.sdk.model.core.role.AmityRoles
import com.ekoapp.ekosdk.internal.api.dto.ChannelMembershipQueryDto
import com.ekoapp.ekosdk.internal.data.AmityNonce
import com.ekoapp.ekosdk.internal.entity.ChannelMembershipEntity
import com.ekoapp.ekosdk.internal.mediator.DynamicQueryStreamMediator
import com.ekoapp.ekosdk.internal.token.DynamicQueryStreamQueryToken
import io.reactivex.Completable
import io.reactivex.Flowable
import io.reactivex.Single


internal class ChannelMembershipMediator(
    private val channelId: String,
    private val memberships: List<AmityMembershipType>,
    private val isMuted: Boolean?,
    private val roles: AmityRoles,
    private val sortOption: AmityChannelMembershipSortOption?
) : DynamicQueryStreamMediator<ChannelMembershipEntity, ChannelMembershipQueryDto, AmityChannelMember>(
    nonce = AmityNonce.CHANNEL_MEMBERSHIP,
    dynamicQueryStreamKeyCreator = ChannelMembershipKeyCreator(
        channelId = channelId,
        memberships = memberships,
        isMuted = isMuted,
        roles = roles,
        sortOption = sortOption
    )
) {

    override fun forceRefresh() = true

    override fun provideReactorPublisher(): Flowable<AmityChannelMember> {
        return ChannelMembershipRepository().getLatestChannel(
            channelId = channelId,
            memberships = memberships,
            isMuted = isMuted,
            roles = roles,
            dynamicQueryStreamKeyCreator = dynamicQueryStreamKeyCreator,
            nonce = nonce
        ).toRx2()
    }

    override fun getFirstPageRequest(pageSize: Int): Single<ChannelMembershipQueryDto> {
        return getRequest(limit = pageSize)
    }

    override fun getFetchByTokenRequest(token: String): Single<ChannelMembershipQueryDto> {
        return getRequest(token = token)
    }

    override fun persistResponse(dto: ChannelMembershipQueryDto): Completable {
        return ChannelMembershipQueryPersister().persist(dto).toRx2()
    }

    override fun convertResponseToQueryToken(dto: ChannelMembershipQueryDto): DynamicQueryStreamQueryToken {
        return DynamicQueryStreamQueryToken(
            dynamicQueryStreamKeyCreator = dynamicQueryStreamKeyCreator,
            next = dto.token?.next,
            previous = dto.token?.previous,
            primaryKeys = dto.channelMembershipDtoList?.map { it.userId } ?: emptyList()
        )
    }

    private fun getRequest(
        limit: Int? = null,
        token: String? = null
    ): Single<ChannelMembershipQueryDto> {
        return ChannelMembershipRemoteDataStore().queryChannelMembers(
            channelId = channelId,
            roles = roles.get(),
            memberships = generateMembershipParams(memberships, isMuted),
            sortBy  = sortOption?.apiKey,
            options = QueryOptionsRequestParams(limit, token)
        ).toRx2()
    }

    private fun generateMembershipParams(memberships: List<AmityMembershipType>, isMuted: Boolean?) : List<String> {
        return memberships.map { it.apiKey }.plus(if(isMuted != null) listOf(AmityChannelMembership.MUTED.apiKey) else emptyList())
    }

}

==> amity-sdk-7.6.0-sources.jar: main/com/amity/socialcloud/sdk/chat/data/channel/membership/paging/ChannelMembershipMediator.kt <==
package com.amity.socialcloud.sdk.chat.data.channel.membership.paging

import co.amity.rxbridge.toRx2
import com.amity.socialcloud.sdk.api.chat.member.query.AmityChannelMembership
import com.amity.socialcloud.sdk.api.chat.member.query.AmityChannelMembershipSortOption
import com.amity.socialcloud.sdk.chat.data.channel.membership.ChannelMembershipQueryPersister
import com.amity.socialcloud.sdk.chat.data.channel.membership.ChannelMembershipRemoteDataStore
import com.amity.socialcloud.sdk.chat.data.channel.membership.ChannelMembershipRepository
import com.amity.socialcloud.sdk.infra.retrofit.request.QueryOptionsRequestParams
import com.amity.socialcloud.sdk.model.chat.member.AmityChannelMember
import com.amity.socialcloud.sdk.model.chat.member.AmityMembershipType
import com.amity.socialcloud.sdk.model.core.role.AmityRoles
import com.ekoapp.ekosdk.internal.api.dto.ChannelMembershipQueryDto
import com.ekoapp.ekosdk.internal.data.AmityNonce
import com.ekoapp.ekosdk.internal.entity.ChannelMembershipEntity
import com.ekoapp.ekosdk.internal.mediator.DynamicQueryStreamMediator
import com.ekoapp.ekosdk.internal.token.DynamicQueryStreamQueryToken
import io.reactivex.Completable
import io.reactivex.Flowable
import io.reactivex.Single


internal class ChannelMembershipMediator(
    private val channelId: String,
    private val memberships: List<AmityMembershipType>,
    private val isMuted: Boolean?,
    private val roles: AmityRoles,
    private val sortOption: AmityChannelMembershipSortOption?,
    private val isDeleted: Boolean?
) : DynamicQueryStreamMediator<ChannelMembershipEntity, ChannelMembershipQueryDto, AmityChannelMember>(
    nonce = AmityNonce.CHANNEL_MEMBERSHIP,
    dynamicQueryStreamKeyCreator = ChannelMembershipKeyCreator(
        channelId = channelId,
        memberships = memberships,
        isMuted = isMuted,
        roles = roles,
        sortOption = sortOption,
        isDeleted = isDeleted
    )
) {

    override fun forceRefresh() = true

    override fun provideReactorPublisher(): Flowable<AmityChannelMember> {
        return ChannelMembershipRepository().getLatestChannel(
            channelId = channelId,
            memberships = memberships,
            isMuted = isMuted,
            roles = roles,
            dynamicQueryStreamKeyCreator = dynamicQueryStreamKeyCreator,
            nonce = nonce
        ).toRx2()
    }

    override fun getFirstPageRequest(pageSize: Int): Single<ChannelMembershipQueryDto> {
        return getRequest(limit = pageSize)
    }

    override fun getFetchByTokenRequest(token: String): Single<ChannelMembershipQueryDto> {
        return getRequest(token = token)
    }

    override fun persistResponse(dto: ChannelMembershipQueryDto): Completable {
        return ChannelMembershipQueryPersister().persist(dto).toRx2()
    }

    override fun convertResponseToQueryToken(dto: ChannelMembershipQueryDto): DynamicQueryStreamQueryToken {
        return DynamicQueryStreamQueryToken(
            dynamicQueryStreamKeyCreator = dynamicQueryStreamKeyCreator,
            next = dto.token?.next,
            previous = dto.token?.previous,
            primaryKeys = dto.channelMembershipDtoList?.map { it.userId } ?: emptyList()
        )
    }

    private fun getRequest(
        limit: Int? = null,
        token: String? = null
    ): Single<ChannelMembershipQueryDto> {
        return ChannelMembershipRemoteDataStore().queryChannelMembers(
            channelId = channelId,
            roles = roles.get(),
            memberships = generateMembershipParams(memberships, isMuted),
            sortBy  = sortOption?.apiKey,
            isDeleted = isDeleted,
            options = QueryOptionsRequestParams(limit, token)
        ).toRx2()
    }

    private fun generateMembershipParams(memberships: List<AmityMembershipType>, isMuted: Boolean?) : List<String> {
        return memberships.map { it.apiKey }.plus(if(isMuted != null) listOf(AmityChannelMembership.MUTED.apiKey) else emptyList())
    }

}
